@@ -448,6 +448,16 @@ gnome_vfs_set_file_info_cancellable (GnomeVFSURI *a,
 
 	if (!VFS_METHOD_HAS_FUNC(a->method, set_file_info))
 		return GNOME_VFS_ERROR_NOT_SUPPORTED;
+		
+	if (mask & GNOME_VFS_SET_FILE_INFO_NAME) {
+		if (strchr (info->name, '/') != NULL
+#ifdef G_OS_WIN32
+		    || strchr (info->name, '\\') != NULL
+#endif
+		    ) {
+			return GNOME_VFS_ERROR_BAD_PARAMETERS;
+		}
+	}
 
 	return a->method->set_file_info (a->method, a, info, mask, context);
 }
