@@ -3,7 +3,6 @@
 
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 #include <glib-object.h>
 
 /* enumerations from "gnome-vfs-directory.h" */
@@ -23,7 +22,6 @@ gnome_vfs_directory_visit_options_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-file-info.h" */
 GType
 gnome_vfs_file_flags_get_type (void)
@@ -40,7 +38,6 @@ gnome_vfs_file_flags_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_file_type_get_type (void)
 {
@@ -61,7 +58,6 @@ gnome_vfs_file_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_file_info_fields_get_type (void)
 {
@@ -90,7 +86,6 @@ gnome_vfs_file_info_fields_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_file_permissions_get_type (void)
 {
@@ -121,7 +116,6 @@ gnome_vfs_file_permissions_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_file_info_options_get_type (void)
 {
@@ -140,7 +134,6 @@ gnome_vfs_file_info_options_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_set_file_info_mask_get_type (void)
 {
@@ -159,7 +152,6 @@ gnome_vfs_set_file_info_mask_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-find-directory.h" */
 GType
 gnome_vfs_find_directory_kind_get_type (void)
@@ -176,7 +168,6 @@ gnome_vfs_find_directory_kind_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-handle.h" */
 GType
 gnome_vfs_open_mode_get_type (void)
@@ -188,13 +179,13 @@ gnome_vfs_open_mode_get_type (void)
       { GNOME_VFS_OPEN_READ, "GNOME_VFS_OPEN_READ", "read" },
       { GNOME_VFS_OPEN_WRITE, "GNOME_VFS_OPEN_WRITE", "write" },
       { GNOME_VFS_OPEN_RANDOM, "GNOME_VFS_OPEN_RANDOM", "random" },
+      { GNOME_VFS_OPEN_TRUNCATE, "GNOME_VFS_OPEN_TRUNCATE", "truncate" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GnomeVFSOpenMode", values);
   }
   return etype;
 }
-
 GType
 gnome_vfs_seek_position_get_type (void)
 {
@@ -211,6 +202,39 @@ gnome_vfs_seek_position_get_type (void)
   return etype;
 }
 
+/* enumerations from "gnome-vfs-mime-deprecated.h" */
+GType
+gnome_vfs_mime_action_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GNOME_VFS_MIME_ACTION_TYPE_NONE, "GNOME_VFS_MIME_ACTION_TYPE_NONE", "none" },
+      { GNOME_VFS_MIME_ACTION_TYPE_APPLICATION, "GNOME_VFS_MIME_ACTION_TYPE_APPLICATION", "application" },
+      { GNOME_VFS_MIME_ACTION_TYPE_COMPONENT, "GNOME_VFS_MIME_ACTION_TYPE_COMPONENT", "component" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GnomeVFSMimeActionType", values);
+  }
+  return etype;
+}
+
+/* enumerations from "gnome-vfs-mime-handlers.h" */
+GType
+gnome_vfs_mime_application_argument_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS, "GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS", "uris" },
+      { GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_PATHS, "GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_PATHS", "paths" },
+      { GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS_FOR_NON_FILES, "GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS_FOR_NON_FILES", "uris-for-non-files" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GnomeVFSMimeApplicationArgumentType", values);
+  }
+  return etype;
+}
 
 /* enumerations from "gnome-vfs-mime-utils.h" */
 GType
@@ -229,41 +253,6 @@ gnome_vfs_mime_equivalence_get_type (void)
   return etype;
 }
 
-
-/* enumerations from "gnome-vfs-mime-handlers.h" */
-GType
-gnome_vfs_mime_action_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GNOME_VFS_MIME_ACTION_TYPE_NONE, "GNOME_VFS_MIME_ACTION_TYPE_NONE", "none" },
-      { GNOME_VFS_MIME_ACTION_TYPE_APPLICATION, "GNOME_VFS_MIME_ACTION_TYPE_APPLICATION", "application" },
-      { GNOME_VFS_MIME_ACTION_TYPE_COMPONENT, "GNOME_VFS_MIME_ACTION_TYPE_COMPONENT", "component" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GnomeVFSMimeActionType", values);
-  }
-  return etype;
-}
-
-GType
-gnome_vfs_mime_application_argument_type_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS, "GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS", "uris" },
-      { GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_PATHS, "GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_PATHS", "paths" },
-      { GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS_FOR_NON_FILES, "GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS_FOR_NON_FILES", "uris-for-non-files" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("GnomeVFSMimeApplicationArgumentType", values);
-  }
-  return etype;
-}
-
-
 /* enumerations from "gnome-vfs-monitor.h" */
 GType
 gnome_vfs_monitor_type_get_type (void)
@@ -279,7 +268,6 @@ gnome_vfs_monitor_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_monitor_event_type_get_type (void)
 {
@@ -299,7 +287,6 @@ gnome_vfs_monitor_event_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-result.h" */
 GType
 gnome_vfs_result_get_type (void)
@@ -365,7 +352,6 @@ gnome_vfs_result_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-standard-callbacks.h" */
 GType
 gnome_vfs_module_callback_full_authentication_flags_get_type (void)
@@ -385,7 +371,6 @@ gnome_vfs_module_callback_full_authentication_flags_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_module_callback_full_authentication_out_flags_get_type (void)
 {
@@ -400,7 +385,6 @@ gnome_vfs_module_callback_full_authentication_out_flags_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-utils.h" */
 GType
 gnome_vfs_make_uri_dirs_get_type (void)
@@ -418,7 +402,6 @@ gnome_vfs_make_uri_dirs_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-volume.h" */
 GType
 gnome_vfs_device_type_get_type (void)
@@ -450,7 +433,6 @@ gnome_vfs_device_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_volume_type_get_type (void)
 {
@@ -467,7 +449,6 @@ gnome_vfs_volume_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gnome-vfs-xfer.h" */
 GType
 gnome_vfs_xfer_options_get_type (void)
@@ -494,7 +475,6 @@ gnome_vfs_xfer_options_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_xfer_progress_status_get_type (void)
 {
@@ -511,7 +491,6 @@ gnome_vfs_xfer_progress_status_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_xfer_overwrite_mode_get_type (void)
 {
@@ -528,7 +507,6 @@ gnome_vfs_xfer_overwrite_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_xfer_overwrite_action_get_type (void)
 {
@@ -546,7 +524,6 @@ gnome_vfs_xfer_overwrite_action_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_xfer_error_mode_get_type (void)
 {
@@ -561,7 +538,6 @@ gnome_vfs_xfer_error_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_xfer_error_action_get_type (void)
 {
@@ -577,7 +553,6 @@ gnome_vfs_xfer_error_action_get_type (void)
   }
   return etype;
 }
-
 GType
 gnome_vfs_xfer_phase_get_type (void)
 {
@@ -609,6 +584,5 @@ gnome_vfs_xfer_phase_get_type (void)
   return etype;
 }
 
-
 /* Generated data ends here */
 
