@@ -35,10 +35,9 @@
 #include "gnome-vfs-mime.h"
 #include "gnome-vfs-private-utils.h"
 #include "xdgmime.h"
-#include <libgnomevfs/gnome-vfs-i18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <libxml/xmlreader.h>
-#include <dirent.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -63,7 +62,6 @@ static time_t last_checked;
 /* To initialize the module automatically */
 static gboolean gnome_vfs_mime_inited = FALSE;
 
-static GList *current_lang = NULL;
 /* we want to replace the previous key if the current key has a higher
    language level */
 
@@ -123,8 +121,6 @@ gnome_vfs_mime_init (void)
 	/*
 	 * The hash tables that store the mime keys.
 	 */
-	current_lang = gnome_vfs_i18n_get_language_list ("LC_MESSAGES");
-
 	mime_entries = g_hash_table_new_full (g_str_hash, 
 					      g_str_equal,
 					      g_free,
@@ -179,10 +175,10 @@ reload_if_needed (void)
 	if (gnome_mime_dir.force_reload || user_mime_dir.force_reload)
 		need_reload = TRUE;
 	else if (now > last_checked + 5) {
-		if (stat (gnome_mime_dir.dirname, &s) != -1 &&
+		if (g_stat (gnome_mime_dir.dirname, &s) != -1 &&
 		    s.st_mtime != gnome_mime_dir.s.st_mtime)
 			need_reload = TRUE;
-		else if (stat (user_mime_dir.dirname, &s) != -1 &&
+		else if (g_stat (user_mime_dir.dirname, &s) != -1 &&
 			 s.st_mtime != user_mime_dir.s.st_mtime)
 			need_reload = TRUE;
 	}
@@ -258,20 +254,26 @@ gnome_vfs_mime_thaw (void)
 	/* noop, get rid of this once all the mime editing stuff is gone */
 }
 
+/* this gives us a number of the language in the current language list,
+   the lower the number the "better" the translation */
 static int
-language_level (const char *language) 
+language_level (const char *lang)
 {
-        int i;
-        GList *li;
- 
-        if (language == NULL)
-                return 0;
- 
-        for (i = 1, li = current_lang; li != NULL; i++, li = g_list_next (li)) {                if (strcmp ((const char *) li->data, language) == 0)
-                        return i;
-        }
- 
-        return -1;
+	const char * const *lang_list;
+	int i;
+
+	if (lang == NULL)
+		lang = "C";
+
+	/* The returned list is sorted from most desirable to least
+            desirable and always contains the default locale "C". */
+	lang_list = g_get_language_names();
+
+	for (i = 0; lang_list[i]; i++)
+		if (strcmp (lang_list[i], lang) == 0)
+			return i;
+
+	return -1;
 }
 
 static int
@@ -309,7 +311,7 @@ handle_simple_string (xmlTextReaderPtr reader)
 			if (text != NULL) {
 				g_free (text);
 			}
-			text = g_strdup (xmlTextReaderConstValue (reader));
+			text = g_strdup ((char *)xmlTextReaderConstValue (reader));
 		}
 
 		ret = read_next (reader);
@@ -324,9 +326,9 @@ handle_attribute (xmlTextReaderPtr  reader,
 	xmlChar *xml_text = NULL;
 	char *text = NULL;
 
-	xml_text = xmlTextReaderGetAttribute (reader, attribute);
+	xml_text = xmlTextReaderGetAttribute (reader, (guchar *)attribute);
 	if (xml_text != NULL) {
-		text = g_strdup (xml_text);
+		text = g_strdup ((char *)xml_text);
 		xmlFree (xml_text);
 	}
 	return text;
@@ -338,7 +340,7 @@ handle_mime_info (const char *filename, xmlTextReaderPtr reader)
 	MimeEntry *entry;
 	int ret;
 	int depth;
-	int previous_lang_level = -1;
+	int previous_lang_level = INT_MAX;
 	
 	entry = g_new0 (MimeEntry, 1);
 
@@ -351,17 +353,18 @@ handle_mime_info (const char *filename, xmlTextReaderPtr reader)
 		
 		if (type == XML_READER_TYPE_ELEMENT) {
 			const char *name;
-			name = xmlTextReaderConstName (reader);
+			name = (char *)xmlTextReaderConstName (reader);
 			
 			if (!strcmp (name, "comment")) {
 				const char *lang;
 				int lang_level;
 				
-				lang = xmlTextReaderConstXmlLang (reader);
+				lang = (char *)xmlTextReaderConstXmlLang (reader);
 				
 				lang_level = language_level (lang);
 				
-				if (lang_level > previous_lang_level) {
+				if (lang_level != -1 &&
+				    lang_level < previous_lang_level) {
 					char *comment;
 					comment = handle_simple_string (reader);
 					g_free (entry->description);
