@@ -79,9 +79,9 @@ enum {
 static gint64
 system_time (void)
 {
-	struct timeval time_of_day;
+	GTimeVal time_of_day;
 
-	gettimeofday (&time_of_day, NULL);
+	g_get_current_time (&time_of_day);
 	return (gint64) time_of_day.tv_usec + ((gint64) time_of_day.tv_sec) * 1000000;
 }
 
@@ -101,6 +101,7 @@ init_progress (GnomeVFSProgressCallbackState *progress_state,
 	progress_info->bytes_copied = 0;
 	progress_info->total_bytes_copied = 0;
 	progress_info->duplicate_name = NULL;
+	progress_info->duplicate_count = 0;
 	progress_info->top_level_item = FALSE;
 
 	progress_state->progress_info = progress_info;
@@ -1681,28 +1682,36 @@ copy_directory (GnomeVFSFileInfo *source_file_info,
 	gnome_vfs_directory_close (dest_directory_handle);
 	gnome_vfs_directory_close (source_directory_handle);
 
-	if (result == GNOME_VFS_OK) {
+	if (result == GNOME_VFS_OK) {			
 		GnomeVFSFileInfo *info;
-		info = gnome_vfs_file_info_new ();
+
+		if (target_dir_info && GNOME_VFS_FILE_INFO_SGID (target_dir_info)) {
+			info = gnome_vfs_file_info_dup (source_file_info);
+			info->gid = target_dir_info->gid;
+		} else {
+			/* No need to dup the file info in this case */
+			gnome_vfs_file_info_ref (source_file_info);
+			info = source_file_info;
+		}
+		
 		/* FIXME the modules should ignore setting of permissions if
 		 * "valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS" is clear
 		 * for now, make sure permissions aren't set to 000
 		 */
-		gnome_vfs_file_info_copy (source_file_info, info);
-		if (target_dir_info && GNOME_VFS_FILE_INFO_SGID(target_dir_info)) {
-			info->gid = target_dir_info->gid;
-		}
-		if ((source_file_info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS) != 0) {
+		if ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_PERMISSIONS) != 0) {
+			
 			/* Call this separately from the time one, since one of them may fail,
 			   making the other not run. */
 			gnome_vfs_set_file_info_uri (target_dir_uri, info, 
-						     GNOME_VFS_SET_FILE_INFO_OWNER | GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
+						     GNOME_VFS_SET_FILE_INFO_OWNER | 
+						     GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
 		}
 		
 		/* Call this last so nothing else changes the times */
 		gnome_vfs_set_file_info_uri (target_dir_uri, info, GNOME_VFS_SET_FILE_INFO_TIME);
 		gnome_vfs_file_info_unref (info);
 	}
+	
 	if (target_dir_info) {
 		gnome_vfs_file_info_unref (target_dir_info);
 	}
@@ -2149,6 +2158,7 @@ gnome_vfs_xfer_delete_items_common (const GList *source_uri_list,
 						      GNOME_VFS_FILE_INFO_DEFAULT);
 
 		if (result != GNOME_VFS_OK) {
+			gnome_vfs_file_info_unref (info);
 			break;
 		}
 
@@ -2160,6 +2170,8 @@ gnome_vfs_xfer_delete_items_common (const GList *source_uri_list,
 			result = remove_file (uri, progress, xfer_options, &error_mode,
 					      &skip);
 		}
+
+		gnome_vfs_file_info_unref (info);
 	}
 
 	return result;
